from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Audio = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AD1853', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD1853'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'audio dac 2ch 24bit 192kHz', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD1853.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAD1853\n\naudio dac 2ch 24bit 192kHz', 'pins':[
            Pin(num='1',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OUTL+',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OUTL-',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='FILTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='FCR',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OUTR-',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUTR+',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='FILTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IDPM1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='IDPM0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='ZEROL',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='L/~{R}CLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='BCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SDATA',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CLATCH',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CDATA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='INT4X',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='INT2X',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ZEROR',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='DEEMP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD1855', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD1855'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'audio dac 2ch 24bit 96kHz', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD1855.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAD1855\n\naudio dac 2ch 24bit 96kHz', 'pins':[
            Pin(num='1',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='96/~{48}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OUTR+',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OUTR-',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='FILTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='OUTL-',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUTL+',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='FILTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IDPM1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='IDPM0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='ZEROL',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{PD/RST}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='L/~{R}CLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='BCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SDATA',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CLATCH',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CDATA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='384/~{256}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ZEROR',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='DEEMP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD1955', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD1955'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'audio dac 2ch 24bit 192kHz', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD1955.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAD1955\n\naudio dac 2ch 24bit 192kHz', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='OUTR+',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUTR-',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='FILTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='IREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='FILTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUTL-',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='OUTL+',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='LRCLK/EF_WCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ZEROR',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='ZEROL',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{PD/RST}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CDATA',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{CLATCH}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='CCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='BCLK/EF_BCLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SDATA/EF_LDATA',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='EF_RDATA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DSD_SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DSD_LDATA',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DSD_RDATA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DSD_PHASE',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADAU1978xBCP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADAU1978xBCP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-40-1EP_6x6mm_P0.5mm_EP3.9x3.9mm'], 'footprint':'Package_CSP:LFCSP-40-1EP_6x6mm_P0.5mm_EP3.9x3.9mm', 'keywords':'Audio ADC I2S TDM', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADAU1978.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nADAU1978xBCP\n\nAudio ADC I2S TDM', 'pins':[
            Pin(num='1',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DVDD',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='IOVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SDATAOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SDATAOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='LRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='BCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='ADDR0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='ADDR1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PLL_FILT',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AIN1N',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='AIN1P',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='AIN2N',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='AIN2P',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='AIN3N',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='AIN3P',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='AIN4N',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='AIN4P',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{PD}/~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='MCLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='SA_MODE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AK5392VS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AK5392VS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x18.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x18.7mm_P1.27mm', 'keywords':'audio adc 2ch 24bit', 'description':'', 'datasheet':'https://media.digikey.com/pdf/Data%20Sheets/AKM%20Semiconductor%20Inc.%20PDFs/AK5392.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAK5392VS\n\naudio adc 2ch 24bit', 'pins':[
            Pin(num='1',name='VREFL',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SMODE2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SMODE1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDATA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='FSYNC',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='CMODE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='HPFE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GNDL',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AINR-',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AINR+',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VCOMR',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='GNDR',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='VREFR',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VCOML',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AINL+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINL-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ZCAL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CAL',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AK5393VS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AK5393VS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x18.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x18.7mm_P1.27mm', 'keywords':'audio adc 2ch 24bit 96kHz', 'description':'', 'datasheet':'https://www.akm.com/akm/en/file/datasheet/AK5393VS.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAK5393VS\n\naudio adc 2ch 24bit 96kHz', 'pins':[
            Pin(num='1',name='VREFL',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SMODE2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SMODE1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDATA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='FSYNC',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DFS',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='HPFE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GNDL',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AINR-',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AINR+',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VCOMR',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='GNDR',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='VREFR',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VCOML',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AINL+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINL-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ZCAL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CAL',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AK5394AVS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AK5394AVS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x18.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x18.7mm_P1.27mm', 'keywords':'audio adc 2ch 24bit 192kHz', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/AK5394AVS.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAK5394AVS\n\naudio adc 2ch 24bit 192kHz', 'pins':[
            Pin(num='1',name='VREFL+',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SMODE2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SMODE1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDATA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='FSYNC',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DFS0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='HPFE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VREFL-',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='DFS1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AINR-',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AINR+',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VCOMR',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='VREFR-',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='VREFR+',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VCOML',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AINL+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINL-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ZCAL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CAL',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AK5720VT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AK5720VT'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'audio adc 2ch 24bit 96kHz I2S MSB TDM', 'description':'', 'datasheet':'https://www.akm.com/akm/en/file/datasheet/AK5720VT.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAK5720VT\n\naudio adc 2ch 24bit 96kHz I2S MSB TDM', 'pins':[
            Pin(num='1',name='VCOM',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='LRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='BICK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{PDN}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DIF/TDMI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='FSEL',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CKS',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LIN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GSEL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='REGO',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='SDTO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AK7742EQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AK7742EQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'audio adc 2ch dac 4ch dsp', 'description':'', 'datasheet':'https://www.akm.com/akm/en/file/datasheet/AK7742EQ.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAK7742EQ\n\naudio adc 2ch dac 4ch dsp', 'pins':[
            Pin(num='1',name='AIN3L',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='XTI',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='XTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SDOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SDIN1/JX1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDIN2/JX2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CKM1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='CKM0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{IRESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='I2CSEL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AIN2R',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VSS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='BICK',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CLKO/SDOUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='SO/RDY/GPO/SDOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='CAD0',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='CAD1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AIN2L',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='AVDRV',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='AOUT2RN',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='AOUT2RP',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='AOUT2LN',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='AOUT2LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='AOUT1RN',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='AOUT1RP',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='AOUT1LN',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='AOUT1LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='VSS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VCOM',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='AIN1RN',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='AIN1RP',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='AIN1LN',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='AIN1LP',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='AIN3R',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='LFLT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='TEST1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='CKM2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DVDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS3310', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS3310'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'VCEG CEM3310 ALFA', 'description':'', 'datasheet':'http://www.alfarzpp.lv/eng/sc/AS3310.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAS3310\n\nVCEG CEM3310 ALFA', 'pins':[
            Pin(num='1',name='CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='IIN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VCR',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCA',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='ATKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='ENVOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VP',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GATE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='TRIG',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CCOMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VCS',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS3320', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS3320'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-18_W7.62mm'], 'footprint':'Package_DIP:DIP-18_W7.62mm', 'keywords':'VCF CEM3320 ALFA', 'description':'', 'datasheet':'http://www.alfarzpp.lv/eng/sc/AS3320.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAS3320\n\nVCF CEM3320 ALFA', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CAP4',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VCFI',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='CAP3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAP2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CAP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VRES',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IRES',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS3320F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS3320F'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm', 'keywords':'VCF CEM3320 ALFA', 'description':'', 'datasheet':'http://www.alfarzpp.lv/eng/sc/AS3320.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAS3320F\n\nVCF CEM3320 ALFA', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VRES',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IRES',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='CAP4',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='VCFI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CAP3',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CAP2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CAP1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS3330', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS3330'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-18_W7.62mm'], 'footprint':'Package_DIP:DIP-18_W7.62mm', 'keywords':'VCA CEM3330 ALFA', 'description':'', 'datasheet':'http://www.alfarzpp.lv/eng/sc/AS3330.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAS3330\n\nVCA CEM3330 ALFA', 'pins':[
            Pin(num='10',name='VCC',func=pin_types.PWRIN),
            Pin(num='18',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='VEE',func=pin_types.PWRIN),
            Pin(num='1',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VG1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DTRIM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCE1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VCL1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IDLE',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CCOMP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CCOMP2',func=pin_types.PASSIVE,unit=2),
            Pin(num='12',name='VCL2',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='IN2',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='VCE2',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='VG2',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='OUT2',func=pin_types.OUTPUT,unit=2),
            Pin(num='17',name='DTRIM2',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '3', '1', '10', '9', '5', '2', '4', '7', '18', '8']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '15', '13', '17', '10', '5', '18', '12', '14', '16']}] }),
        Part(**{ 'name':'AS3330F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS3330F'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm', 'keywords':'VCA CEM3330 ALFA', 'description':'', 'datasheet':'http://www.alfarzpp.lv/eng/sc/AS3330.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAS3330F\n\nVCA CEM3330 ALFA', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PWRIN),
            Pin(num='9',name='VEE',func=pin_types.PWRIN),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='VCE1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VCL1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='IDLE',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='CCOMP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VG1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='DTRIM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='CCOMP2',func=pin_types.PASSIVE,unit=2),
            Pin(num='19',name='VCL2',func=pin_types.INPUT,unit=2),
            Pin(num='2',name='DTRIM2',func=pin_types.PASSIVE,unit=2),
            Pin(num='20',name='IN2',func=pin_types.INPUT,unit=2),
            Pin(num='22',name='VCE2',func=pin_types.INPUT,unit=2),
            Pin(num='23',name='VG2',func=pin_types.INPUT,unit=2),
            Pin(num='24',name='OUT2',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['13', '5', '6', '18', '7', '16', '9', '10', '8', '11', '21', '4', '3', '1', '14', '15', '12']},{'label': 'uB', 'num': 2, 'pin_nums': ['19', '23', '2', '16', '9', '17', '20', '3', '24', '22']}] }),
        Part(**{ 'name':'AS3340', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS3340'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'VCO CEM340 ALFA', 'description':'', 'datasheet':'http://www.alfarzpp.lv/eng/sc/AS3340.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAS3340\n\nVCO CEM340 ALFA', 'pins':[
            Pin(num='1',name='SCALE1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VLFI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VFCI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCALE2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VP',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VPWM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VHSI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VHFT',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSO',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VSSI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS3345', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS3345'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-18_W7.62mm'], 'footprint':'Package_DIP:DIP-18_W7.62mm', 'keywords':'VCO CEM345 ALFA', 'description':'', 'datasheet':'http://www.alfarzpp.lv/eng/sc/AS3340.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAS3345\n\nVCO CEM345 ALFA', 'pins':[
            Pin(num='1',name='SCALE1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VSSI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLFI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VFCI',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCALE2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VP',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VPWM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VHSI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VMO',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VHFT',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VSO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS3345F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS3345F'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm', 'keywords':'VCO CEM345 ALFA', 'description':'', 'datasheet':'http://www.alfarzpp.lv/eng/sc/AS3340.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAS3345F\n\nVCO CEM345 ALFA', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='VHSI',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VMO',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VHFT',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VSO',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VSSI',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='VTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VFCI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VLFI',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SCALE1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SCALE2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VP',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VPWM',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS3360', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS3360'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'VCA CEM3360 ALFA', 'description':'', 'datasheet':'http://www.alfarzpp.lv/eng/sc/AS3360.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nAS3360\n\nVCA CEM3360 ALFA', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='VEE',func=pin_types.PWRIN),
            Pin(num='2',name='IO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VE1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VC1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='II1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VC2',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='VO2',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='VE2',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='IO2',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='II2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '8', '6', '14', '4', '7', '5', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '10', '9', '12', '13', '14', '11', '7']}] }),
        Part(**{ 'name':'CS4245', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS4245'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'audio codec 2ch 24bit 192kHz', 'description':'', 'datasheet':'https://d3uzseaevmutz1.cloudfront.net/pubs/proDatasheet/CS4245_F3.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS4245\n\naudio codec 2ch 24bit 192kHz', 'pins':[
            Pin(num='1',name='SDA/CDOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AIN2B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN1A',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AIN1B',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AFILTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='AFILTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='VQ1',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VQ2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='FILT1+',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SCL/CCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='FILT2+',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='AIN4A/MICIN1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='AIN4B/MICIN2',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AIN5A',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='AIN5B',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='MICBIAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AIN6A',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN6B',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AUXOUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='AUXOUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='AD0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='AOUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='AOUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='~{MUTEC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VLS',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='LRCK2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AD1/CDIN',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='MCLK2',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='SDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='SCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='LRCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='MCLK1',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='INT',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='OVFL',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VLC',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN3A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN3B',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN2A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS4265', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS4265'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm', 'keywords':'Audio codec 24bit 192khz stereo', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS4265_F5.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS4265\n\nAudio codec 24bit 192khz stereo', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AFILTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='AFILTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='FILT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='MICIN1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MICIN2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='MICBIAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AOUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='AOUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{MUTEC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='VLS',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='TXSDIN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SDIN2',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SDIN1',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='SDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VLC',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='TXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='AINA',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AINB',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS4270', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS4270'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'Audio Codec', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS4270_F1.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS4270\n\nAudio Codec', 'pins':[
            Pin(num='1',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SCL/CCLK/M0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AD0/~{CS}/I2S/~{LJ}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AD1/CDIN/MDIV1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AD2/MDIV2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINA',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='VQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='FIL+',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='LRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='~{MUTEA}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{MUTEB}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VLC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SDA/CDOUT/M1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS4272', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS4272'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'stereo 2ch audio codec i2s 24bit 192kHz', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS4272_F1.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS4272\n\nstereo 2ch audio codec i2s 24bit 192kHz', 'pins':[
            Pin(num='1',name='XT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VL',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SCL/CCLK(M0)',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SDA/CDIN(M1)',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AD0/~{CS}(I2S/~{LJ})',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCOM',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='XTI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='FILT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{AMUTEC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='AOUTA-',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='AOUTA+',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AOUTB+',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='AOUTB-',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{BMUTEC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SDOUT(M/~{S})',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS4334', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS4334'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'stereo 2ch audio codec i2s 24bit 96kHz', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS4334-5-8-9_F7.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS4334\n\nstereo 2ch audio codec i2s 24bit 96kHz', 'pins':[
            Pin(num='1',name='SDATA',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{DEM}/SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AOUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='AOUTL',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS4344', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS4344'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'stereo 2ch audio codec', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS4344-45-48_F2.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS4344\n\nstereo 2ch audio codec', 'pins':[
            Pin(num='1',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AOUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{DEM}/SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='FILT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='AOUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS43L21', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS43L21'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'audio dac 2ch 24bit 96kHz', 'description':'', 'datasheet':'https://d3uzseaevmutz1.cloudfront.net/pubs/proDatasheet/CS43L21_F1.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS43L21\n\naudio dac 2ch 24bit 96kHz', 'pins':[
            Pin(num='1',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AOUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='AOUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VA',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='FILT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='NIC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='TSTO',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='TSTO',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='TSTO',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='SDA/MCLKDIV2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TSTO',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='TSTO',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='TSTO',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='TSTO',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='TSTO',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VL',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='TESTO/M/~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SCL/CCLK/I2S/~{LJ}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='AD0/~{CS}/DEM',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VA_HP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='FLYP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND_HP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='FLYN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VSS_HP',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS5343', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS5343'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'stereo 2ch audio codec', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS5343-44_F5.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS5343\n\nstereo 2ch audio codec', 'pins':[
            Pin(num='1',name='SDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='FILT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='AINL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='AINR',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS5361', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS5361'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'audio adc 2ch 24bit 192kHz', 'description':'', 'datasheet':'https://d3uzseaevmutz1.cloudfront.net/pubs/proDatasheet/CS5361_F2.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS5361\n\naudio adc 2ch 24bit 192kHz', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='MDIV',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{HPF}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I2S/~{LJ}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{OVFL}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINL+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='AINL-',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='M/~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='AINR-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AINR+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VQ',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='REFGND',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='FILT+',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VL',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SDOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS8406', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS8406'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'audio digital interface transmitter 192kHz', 'description':'', 'datasheet':'https://d3uzseaevmutz1.cloudfront.net/pubs/proDatasheet/CS8406_F6.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS8406\n\naudio digital interface transmitter 192kHz', 'pins':[
            Pin(num='12',name='ILRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ISCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='OMCK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VL',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='H/~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TXN',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='TXP',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='SDA/CDOUT/COPY/C',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TEST/APMS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='TEST/TCBLD',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='TCBL',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TEST/CEN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/U',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='TEST/V',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='INT/~{AUDIO}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AD0/~{CS}/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='U/HWCK0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AD1/CDIN/HWCK1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='SCL/CCLK/ORIG',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AD2/~{EMPH}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RXP/SFMT0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='TSTN/SFMT1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='TEST',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS8414', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS8414'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'audio digital interface receiver', 'description':'', 'datasheet':'http://lampizator.eu/LAMPIZATOR/TRANSPORT/CS8414_receiver.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS8414\n\naudio digital interface receiver', 'pins':[
            Pin(num='1',name='C',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='RXN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='FSYNC',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CS12/FCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='U',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='CBL',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SEL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='M3',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='MCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CD/F1',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='FILT',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='ERF',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='SDATA',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='CE/F2',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='VERF',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='CC/F0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='CB/E2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='CA/E1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='C0/E0',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RXP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS8416-xNZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS8416-xNZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm', 'keywords':'audio digital interface receiver', 'description':'', 'datasheet':'https://d3uzseaevmutz1.cloudfront.net/pubs/proDatasheet/CS8416_F3.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS8416-xNZ\n\naudio digital interface receiver', 'pins':[
            Pin(num='1',name='RXP0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RXP7/TXSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AD0/~{CS}/NV/RERR',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AD1/CDIN/~{AUDIO}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCL/CCLK/96KHZ',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDA/CDOUT/RCBL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='U/AD2/GPO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='C/GPO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='TX/GPO0',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VL',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RXN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RMCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OMCK',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OSCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='OLRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RXP3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RXP2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='RXP1',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='TP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='RXP4/RXSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RXP5/RXSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='RXP6/TXSEL1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS8416-xSZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS8416-xSZ'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'audio digital interface receiver', 'description':'', 'datasheet':'https://d3uzseaevmutz1.cloudfront.net/pubs/proDatasheet/CS8416_F3.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS8416-xSZ\n\naudio digital interface receiver', 'pins':[
            Pin(num='1',name='RXP3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RXP4/RXSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RXP5/RXSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RXP6/TXSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RXP7/TXSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='AD0/~{CS}/NV/RERR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AD1/CDIN/~{AUDIO}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCL/CCLK/96KHZ',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SDA/CDOUT/RCBL',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U/AD2/GPO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='C/GPO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='RXP2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TX/GPO0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VL',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='RMCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OMCK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='SDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='OSCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='OLRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RXP1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RXP0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RXN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS8420', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS8420'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'audio sample rate converter', 'description':'', 'datasheet':'https://d3uzseaevmutz1.cloudfront.net/pubs/proDatasheet/CS8420_F4.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS8420\n\naudio sample rate converter', 'pins':[
            Pin(num='1',name='SDA/CDOUT/COPY/C',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RMCK/APMS',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RERR/~{LOCK}/TBCLD',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='ILRCK/TCBLD/RCBL',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ISCLK/PRO/C',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDIN/MUTE/CHS',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='TCBL/NVERR',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='OSCLK/CEN',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='OLRCK/V',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SDOUT/U',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='INT/~{AUDIO}/V/CUVEN',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AD0/~{CS}/DFC0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='U/S/~{AES}/PRO/C',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='OMCK/APMS',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VD+',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='H/~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TXN/U',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='TXP/C',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='AD1/CDIN/DFC1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='SCL/CCLK/ORIG/U',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{EMPH}/U/V',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RXP/SMFT0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RXN/SMFT1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VA+',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~{RST}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSD1794A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSD1794A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'audio dac 2ch 24bit 192kHz', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/dsd1794a.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nDSD1794A\n\naudio dac 2ch 24bit 192kHz', 'pins':[
            Pin(num='1',name='DSDL',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='ADR0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='ADR1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC2R',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND3R',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='IOUTR+',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='IOUTR-',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='AGND1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DSDR',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VCOMR',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='VCOML',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AGND2',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='IOUTL+',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='IOUTL-',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='AGND3L',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VCC2L',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DBCK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PLRCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PDATA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='PBK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD2560E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD2560E'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-I-28_11.8x8mm_P0.55mm'], 'footprint':'Package_SO:TSOP-I-28_11.8x8mm_P0.55mm', 'keywords':'isd2560', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD2560E\n\nisd2560', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD2560P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD2560P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'isd2560', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD2560P\n\nisd2560', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD2560S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD2560S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'isd2560', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD2560S\n\nisd2560', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX98357A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX98357A'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-16-1EP_3x3mm_P0.5mm_EP1.23x1.23mm'], 'footprint':'Package_DFN_QFN:TQFN-16-1EP_3x3mm_P0.5mm_EP1.23x1.23mm', 'keywords':'pcm tdm i2s left-justified amplifier audio dac', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX98357A-MAX98357B.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nMAX98357A\n\npcm tdm i2s left-justified amplifier audio dac', 'pins':[
            Pin(num='1',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUTN',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='LRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='BCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='PAD',func=pin_types.UNSPEC,unit=1),
            Pin(num='2',name='GAIN_SLOT',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{SD_MODE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='OUTP',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MN3005', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MN3005'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Matsushita Panasonic BBD', 'description':'', 'datasheet':'http://www.experimentalistsanonymous.com/diy/Datasheets/MN3005.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nMN3005\n\nMatsushita Panasonic BBD', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CP1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VGG',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MN3007', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MN3007'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Matsushita Panasonic BBD', 'description':'', 'datasheet':'http://www.experimentalistsanonymous.com/diy/Datasheets/MN3007.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nMN3007\n\nMatsushita Panasonic BBD', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VGG',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CP2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MN3207', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MN3207'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Matsushita Panasonic BBD', 'description':'', 'datasheet':'http://www.experimentalistsanonymous.com/diy/Datasheets/MN3207.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nMN3207\n\nMatsushita Panasonic BBD', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VGG',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CP2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSGEQ7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSGEQ7'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'equalizer filter', 'description':'', 'datasheet':'http://mix-sig.com/images/datasheets/MSGEQ7.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nMSGEQ7\n\nequalizer filter', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='STROBE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM1754DBQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM1754DBQ'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'audio dac 24-bit', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/pcm1754.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM1754DBQ\n\naudio dac 24-bit', 'pins':[
            Pin(num='1',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{COM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='ZEROA',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TEST',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DEMP',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='FMT',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V_{OUT}L',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='V_{OUT}R',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM1780', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM1780'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'audio dac 24-bit', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/pcm1780.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM1780\n\naudio dac 24-bit', 'pins':[
            Pin(num='1',name='ZEROL',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='Vcc',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='V_{COM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='V_{OUT}R',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='V_{OUT}L',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='ZEROR',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{MS}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='MC',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='MD',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM1792A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM1792A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'audio dac 2ch 24bit 192kHz', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pcm1792a.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM1792A\n\naudio dac 2ch 24bit 192kHz', 'pins':[
            Pin(num='1',name='ZEROL',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{MS}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='MDI',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='MC',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='MDO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC2R',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND3R',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='IOUTR+',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='IOUTR-',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='AGND1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ZEROR',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='IREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VCOMR',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='VCOML',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AGND2',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='IOUTL+',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='IOUTL-',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='AGND3L',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VCC2L',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='MSEL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM1794A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM1794A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'audio dac 2ch 24bit 192kHz', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pcm1794a.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM1794A\n\naudio dac 2ch 24bit 192kHz', 'pins':[
            Pin(num='1',name='MONO',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='FMT0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='FMT1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ZERO',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC2R',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND3R',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='IOUTR+',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='IOUTR-',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='AGND1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CHSL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VCOMR',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='VCOML',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AGND2',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='IOUTL+',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='IOUTL-',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='AGND3L',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VCC2L',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DEM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM2902', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM2902'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'pcm2902 usb audio', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pcm2902c.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM2902\n\npcm2902 usb audio', 'pins':[
            Pin(num='1',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCCCI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='AGNDC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VINL',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VINR',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCOM',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VOUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VOUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='VCCP1I',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='AGNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VCCP2I',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='XTI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='AGNDX',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VCCXI',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VDDI',func=pin_types.PWROUT,unit=1),
            Pin(num='28',name='~{SSPND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DGNDU',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='HID0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='HID1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='HID2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SEL1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM3060', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM3060'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'audio codec 2ch 24bit 192kHz', 'description':'', 'datasheet':'https://www.ti.com/lit/gpn/pcm3060', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM3060\n\naudio codec 2ch 24bit 192kHz', 'pins':[
            Pin(num='1',name='MC/SCL/FMT',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='BCK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='LRCK2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ZEROR',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='ZEROL',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='V_{OUT}R-',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='V_{OUT}R+',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='V_{OUT}L-',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='MD/SDA/DEMP',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='V_{OUT}L+',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='V_{COM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='AGND2',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='AGND1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='V_{IN}L',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='V_{IN}R',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{MS}/AD/IFMD',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='LRCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='BCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCKI1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SCKI2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM5100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM5100'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'audio dac 2ch 32bit 384kHz', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pcm5100.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM5100\n\naudio dac 2ch 32bit 384kHz', 'pins':[
            Pin(num='1',name='CPVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='DEMP',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='FLT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FMT',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XSMT',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='LDOO',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CAPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAPM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VNEG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM5122PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM5122PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'audio dac 2ch 32bit 384kHz', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pcm5122.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM5122PW\n\naudio dac 2ch 32bit 384kHz', 'pins':[
            Pin(num='1',name='CPVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VCOM/DEMP',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDA/MOSI/ATT2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SCL/MC/ATT1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GPIO5/ATT0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO4/MAST',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO3/AGNS',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='ADR2/GPIO2/DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='MODE1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MODE2/MS',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='GPIO6/FLT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CAPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BCK',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='ADR1/MISO/FMT',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='XSMT',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='LDOO',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAPM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VNEG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PGA2310UA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PGA2310UA'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'audio volume control 2ch spi', 'description':'', 'datasheet':'https://www.ti.com.cn/cn/lit/gpn/pga2310', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPGA2310UA\n\naudio volume control 2ch spi', 'pins':[
            Pin(num='8',name='~{MUTE}',func=pin_types.INPUT),
            Pin(num='1',name='ZCEN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AGNDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='V_{OUT}R',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='V_{A}+',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='V_{A}-',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='V_{OUT}L',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='AGNDL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='V_{IN}L',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V_{D}+',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='V_{IN}R',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PGA2500', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PGA2500'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'Digitally Controlled Microphone Preamplifier', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/pga2500.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPGA2500\n\nDigitally Controlled Microphone Preamplifier', 'pins':[
            Pin(num='1',name='GPO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VD-',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VA-',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='V_{OUT}-',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='V_{OUT}+',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VA+',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VA+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GPO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VA-',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='C_{S22}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='C_{S21}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='C_{S12}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='C_{S11}',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='VIN_{COM}',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='V_{IN}-',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='V_{IN}+',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GPO3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GPO4',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='OVR',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{DCEN}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='0dB',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='ZCEN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PGA4311', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PGA4311'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'audio volume control 4ch spi', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pga4311.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPGA4311\n\naudio volume control 4ch spi', 'pins':[
            Pin(num='1',name='~{MUTE}',func=pin_types.INPUT),
            Pin(num='10',name='Ain-3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AGND_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VD+',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGND_4',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='Ain-4',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AGND_1',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='AGND_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Aout_4',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='VA+',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VA-',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Aout_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='AGND_2',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='Ain-2',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AGND_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='ZCEN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Ain-1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AGND_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Aout_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VA-',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VA+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Aout_3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='AGND_3',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PT2258', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PT2258'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'Volume', 'description':'', 'datasheet':'http://www.princeton.com.tw/Portals/0/Product/PT2258-s.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPT2258\n\nVolume', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='CODE1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CODE2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN5',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PT2399', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PT2399'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'CMOS ADC DAC 44K Digital processing VCO', 'description':'', 'datasheet':'http://www.princeton.com.tw/Portals/0/Product/PT2399_1.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPT2399\n\nCMOS ADC DAC 44K Digital processing VCO', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OP1-IN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OP2-IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='OP2-OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='LPF2-IN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='LPF2-OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='LPF1-OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='LPF1-IN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CLK_O',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='CC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='OP1-OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RD5106A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RD5106A'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EG&G RETICON BBD N-channel silicon-gate', 'description':'', 'datasheet':'http://pdf.datasheetarchive.com/indexerfiles/Scans-091/DSAHI00048836.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nRD5106A\n\nEG&G RETICON BBD N-channel silicon-gate', 'pins':[
            Pin(num='1',name='Clock',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='Output',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Input',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Sync',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RE46C317', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RE46C317'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Microchip step-up', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/22301B.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nRE46C317\n\nMicrochip step-up', 'pins':[
            Pin(num='1',name='FEED',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='LX',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='V_{O}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='HORNB',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='HORNS',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='HRNEN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SAD1024', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SAD1024'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EG&G RETICON BBD N-channel silicon-gate', 'description':'', 'datasheet':'http://thmq.mysteria.cz/em1022/SAD1024.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nSAD1024\n\nEG&G RETICON BBD N-channel silicon-gate', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT),
            Pin(num='7',name='Vdd',func=pin_types.PWRIN),
            Pin(num='9',name='Vbb',func=pin_types.PWRIN),
            Pin(num='2',name='IN_A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='02A',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name="OUT_A'",func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='01A',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='01B',func=pin_types.INPUT,unit=2),
            Pin(num='11',name="OUT_B'",func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='OUT_B',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='02B',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='IN_B',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '6', '4', '13', '7', '3', '8', '16', '9', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '1', '14', '4', '13', '7', '11', '9', '15', '16', '12']}] }),
        Part(**{ 'name':'SGTL5000XNAA3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SGTL5000XNAA3'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm', 'keywords':'Codec', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/SGTL5000.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nSGTL5000XNAA3\n\nCodec', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VAG',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='LINEOUT_R',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='LINEOUT_L',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='LINEIN_R',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='LINEIN_L',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='MIC_BIAS',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='CPFILT',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='HP_R',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='SYS_MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='I2S_LRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='I2S_SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='I2S_DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='I2S_DIN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='CTRL_DATA',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='CTRL_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='CTRL_ADR0_CS',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='CTRL_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='HP_VGND',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='HP_L',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SGTL5000XNLA3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SGTL5000XNLA3'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.4mm_EP1.65x1.65mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.4mm_EP1.65x1.65mm', 'keywords':'Codec', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/SGTL5000.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nSGTL5000XNLA3\n\nCodec', 'pins':[
            Pin(num='1',name='HP_R',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='MIC_BIAS',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SYS_MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I2S_LRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='I2S_SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='I2S_DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='I2S_DIN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='CTRL_DATA',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CTRL_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='HP_VGND',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='HP_L',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VAG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='LINEOUT_R',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='LINEOUT_L',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='LINEIN_R',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='LINEIN_L',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SPN1001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SPN1001'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'SpinSemi FV-1 SPN1001', 'description':'', 'datasheet':'http://www.spinsemi.com/Products/datasheets/spn1001/FV-1.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nSPN1001\n\nSpinSemi FV-1 SPN1001', 'pins':[
            Pin(num='1',name='LIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='T1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='T0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RIN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='POT0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='POT1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='POT2',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='REFN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='REFP',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='ROUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='LOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MID',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CLIP',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='X2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SRC4392xPFB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SRC4392xPFB'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'audio sample rate converter', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/src4392.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nSRC4392xPFB\n\naudio sample rate converter', 'pins':[
            Pin(num='1',name='RX1+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{LOCK}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RXCKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RXCKI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{RDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DGND1',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD18',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='CPM',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}/A0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RX1-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='CCLK/SCL',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='CDIN/A1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CDOUT/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='24',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='GPO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='GPO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='GPO3',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='GPO4',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RX2+',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DGND2',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TX-',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='TX+',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='AESOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='BLS',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='SYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='BCKA',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='LRCKA',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='SDINA',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RX2-',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='SDOUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='DGND3',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='BGND',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='SDOUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='SDINB',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='LRCKB',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BCKB',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RX3+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RX3-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='RX4+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RX4-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SSI2144', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SSI2144'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'Sound Semiconductor VCF SSM2044', 'description':'', 'datasheet':'http://www.soundsemiconductor.com/downloads/ssi2144datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nSSI2144\n\nSound Semiconductor VCF SSM2044', 'pins':[
            Pin(num='1',name='SIG_IN+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='C2B',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='C2A',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='C1B',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='C1A',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Q_CTRL',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='FREQ_CTRL',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SIG_IN-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='C4A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='C4B',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='C3A',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='C3B',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SSI2164', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SSI2164'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'Sound Semiconductor VCA SSM2164', 'description':'', 'datasheet':'http://www.soundsemiconductor.com/downloads/ssi2164datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nSSI2164\n\nSound Semiconductor VCA SSM2164', 'pins':[
            Pin(num='1',name='MODE',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='I_IN3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VC3',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='I_OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='I_OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VC4',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='I_IN4',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I_IN1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='I_OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='I_OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VC2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='I_IN2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='V-',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA1022', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA1022'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'PHILIPS BBD MOS monolithic delay analogue', 'description':'', 'datasheet':'http://thmq.mysteria.cz/em1022/TDA1022.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTDA1022\n\nPHILIPS BBD MOS monolithic delay analogue', 'pins':[
            Pin(num='1',name='CL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='Output512',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='V13-16',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='CL2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Input',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='Output513',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THAT1580', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT1580'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias', 'keywords':'diff amp mic preamp', 'description':'', 'datasheet':'http://www.thatcorp.com/datashts/THAT_1580_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTHAT1580\n\ndiff amp mic preamp', 'pins':[
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='Rg2',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='V-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Rg1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IN1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THAT5171', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT5171'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP5.4x5.4mm', 'keywords':'mic preamp gain controller', 'description':'', 'datasheet':'http://www.thatcorp.com/datashts/THAT_5171_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTHAT5171\n\nmic preamp gain controller', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='SCAP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Rg1',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='SCAP2',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='SOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='SOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Rg2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DGND',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=2),
            Pin(num='14',name='TRC',func=pin_types.PASSIVE,unit=2),
            Pin(num='15',name='~{RST}',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='~{CS}',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='SCLK',func=pin_types.INPUT,unit=2),
            Pin(num='18',name='DIN',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='DOUT',func=pin_types.TRISTATE,unit=2),
            Pin(num='20',name='DGND',func=pin_types.PASSIVE,unit=2),
            Pin(num='21',name='VDD',func=pin_types.PASSIVE,unit=2),
            Pin(num='22',name='BSY',func=pin_types.OUTPUT,unit=2),
            Pin(num='23',name='GPO0',func=pin_types.BIDIR,unit=2),
            Pin(num='24',name='GPO1',func=pin_types.BIDIR,unit=2),
            Pin(num='25',name='GPO2',func=pin_types.BIDIR,unit=2),
            Pin(num='26',name='GPO3',func=pin_types.BIDIR,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['29', '10', '28', '31', '1', '33', '5', '8', '3', '7', '4', '6', '9', '11', '27', '32', '30', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['20', '12', '14', '16', '21', '22', '24', '15', '13', '17', '19', '23', '25', '26', '18']}] }),
        Part(**{ 'name':'THAT5173', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT5173'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.4x3.4mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.4x3.4mm', 'keywords':'mic preamp gain controller', 'description':'', 'datasheet':'http://www.thatcorp.com/datashts/THAT_5173_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTHAT5173\n\nmic preamp gain controller', 'pins':[
            Pin(num='1',name='SCAP2',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Rg1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='SOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='SOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='SCAP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Rg2',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='TRC',func=pin_types.PASSIVE,unit=2),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=2),
            Pin(num='12',name='DGND',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='DOUT',func=pin_types.TRISTATE,unit=2),
            Pin(num='14',name='BSY',func=pin_types.OUTPUT,unit=2),
            Pin(num='15',name='GPO0',func=pin_types.OUTPUT,unit=2),
            Pin(num='16',name='GPO1',func=pin_types.OUTPUT,unit=2),
            Pin(num='17',name='GPO2',func=pin_types.OUTPUT,unit=2),
            Pin(num='18',name='GPO3',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='~{RST}',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~{CS}',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='SCLK',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='DIN',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['23', '21', '5', '1', '2', '24', '19', '22', '4', '25', '3', '20']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '14', '16', '18', '7', '9', '11', '13', '15', '17', '6', '8', '12']}] }),
        Part(**{ 'name':'THAT5263', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT5263'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.4x3.4mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.4x3.4mm', 'keywords':'dual mic preamp gain controller', 'description':'', 'datasheet':'http://www.thatcorp.com/datashts/THAT_5263_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTHAT5263\n\ndual mic preamp gain controller', 'pins':[
            Pin(num='10',name='IN2_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IN1_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RA_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RG1_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='RG2_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='RB_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='SCLK',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='DIN',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='DOUT',func=pin_types.TRISTATE,unit=2),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=2),
            Pin(num='16',name='DGND',func=pin_types.PWRIN,unit=2),
            Pin(num='17',name='BSY_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='18',name='BSY_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='19',name='GPO_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='20',name='GPO_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='1',name='RB_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='2',name='IN2_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='21',name='IN1_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='22',name='RA_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='23',name='RG1_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='24',name='RG2_CH2',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '10', '25', '6', '3', '9', '7', '5', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '15', '17', '13', '19', '12', '14', '16', '18', '20']},{'label': 'uC', 'num': 3, 'pin_nums': ['1', '21', '23', '2', '22', '24']}] }),
        Part(**{ 'name':'THAT6261', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT6261'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.45x5.45mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.45x5.45mm', 'keywords':'dual mic preamp', 'description':'', 'datasheet':'http://www.thatcorp.com/datashts/THAT_626x_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTHAT6261\n\ndual mic preamp', 'pins':[
            Pin(num='1',name='RFB+_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VA+',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CG2_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CG1_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='IN-_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN+_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VA-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CFB-_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VA-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CFB+_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VA+',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VCM',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VAD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='OUT-_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='OUT+_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='RFB-_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DI+_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DI-_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PO+_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PO-_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VA-',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GPO0_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='26',name='GPO1_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='27',name='BSY_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='28',name='DGND',func=pin_types.PWRIN,unit=2),
            Pin(num='29',name='VD',func=pin_types.PWRIN,unit=2),
            Pin(num='30',name='~{CS}',func=pin_types.INPUT,unit=2),
            Pin(num='31',name='SCLK',func=pin_types.INPUT,unit=2),
            Pin(num='32',name='DIN',func=pin_types.INPUT,unit=2),
            Pin(num='33',name='DOUT',func=pin_types.TRISTATE,unit=2),
            Pin(num='34',name='BSY_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='35',name='GPO_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='36',name='GP1_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='16',name='CG2_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='17',name='CG1_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='18',name='IN-_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='19',name='IN+_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='21',name='PO+_CH2',func=pin_types.OUTPUT,unit=3),
            Pin(num='22',name='PO-_CH2',func=pin_types.OUTPUT,unit=3),
            Pin(num='23',name='DI+_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='24',name='DI-_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='37',name='CFB+_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='38',name='CFB-_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='39',name='RFB+_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='40',name='RFB-_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='41',name='OUT+_CH2',func=pin_types.OUTPUT,unit=3),
            Pin(num='42',name='OUT-_CH2',func=pin_types.OUTPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['10', '45', '8', '15', '46', '9', '20', '47', '2', '1', '48', '3', '49', '11', '4', '5', '12', '14', '43', '6', '13', '44', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['29', '25', '27', '31', '33', '35', '28', '26', '30', '32', '34', '36']},{'label': 'uC', 'num': 3, 'pin_nums': ['23', '41', '16', '18', '21', '37', '22', '24', '38', '39', '40', '42', '19', '17']}] }),
        Part(**{ 'name':'TLV320AIC23BPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV320AIC23BPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'audio codec 2ch 96kHz headphone amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlv320aic23b.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTLV320AIC23BPW\n\naudio codec 2ch 96kHz headphone amplifier', 'pins':[
            Pin(num='1',name='BVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RHPOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='HPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='LOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='ROUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VMID',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='MICBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='MICIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='RLINEIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='LLINEIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XTI/MCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='XTO',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='BCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='LRCIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='LRCOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='HPVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='LHPOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV320AIC23BRHD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV320AIC23BRHD'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm', 'keywords':'audio codec 2ch 96kHz headphone amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlv320aic23b.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTLV320AIC23BRHD\n\naudio codec 2ch 96kHz headphone amplifier', 'pins':[
            Pin(num='1',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ROUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VMID',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='MICBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='MICIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='RLINEIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='LLINEIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='LRCIN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='XTI/MCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='XTO',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='BVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='BCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='LRCOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='HPVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='LHPOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RHPOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='HPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='LOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV320AIC23BxQE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV320AIC23BxQE'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm', 'keywords':'audio codec 2ch 96kHz headphone amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlv320aic23b.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTLV320AIC23BxQE\n\naudio codec 2ch 96kHz headphone amplifier', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='HPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='RHPOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='LHPOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='HPVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='LRCOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='A7',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='A8',name='LRCIN',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B1',name='LOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B9',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='C1',name='ROUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C9',name='BCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D9',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='E1',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E9',name='BVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VMID',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='MICBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G9',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='MICIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='H2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H9',name='XTO',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J2',name='RLINEIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='LLINEIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='J5',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='J6',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='J7',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='J8',name='XTI/MCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV320AIC3100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV320AIC3100'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-32-1EP_5x5mm_P0.5mm_EP3.5x3.5mm'], 'footprint':'Package_DFN_QFN:VQFN-32-1EP_5x5mm_P0.5mm_EP3.5x3.5mm', 'keywords':'audio codec 2ch 192kHz class-d amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlv320aic3100.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTLV320AIC3100\n\naudio codec 2ch 192kHz class-d amplifier', 'pins':[
            Pin(num='1',name='IOVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VOL/MICDET',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='MICBIAS',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='MIC1LP',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='MIC1RP',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MIC1LM',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SPKM',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IOVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SPKVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='SPKVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='SPKP',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='SPKM',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='SPKVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='SPKVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='SPKP',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='HPL',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='HPVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='HPVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='HPR',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='WCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='BCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPA5050', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPA5050'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_S-PVQFN-N16_EP2.7x2.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Texas_S-PVQFN-N16_EP2.7x2.7mm_ThermalVias', 'keywords':'audio delay', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpa5050.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTPA5050\n\naudio delay', 'pins':[
            Pin(num='1',name='LRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ADD0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='ADD1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='ADD2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='DATA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='BCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UDA1334ATS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UDA1334ATS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_4.4x5.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-16_4.4x5.2mm_P0.65mm', 'keywords':'audio dac 2ch 24bit 96kHz', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/UDA1334ATS.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nUDA1334ATS\n\naudio dac 2ch 24bit 96kHz', 'pins':[
            Pin(num='1',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PLL0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SFOR0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Vref(DAC)',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VOUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VOUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='WS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DATAI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SYSCLK/PLL1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SFOR1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DEEM/CLKOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'WM8731CLSEFL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WM8731CLSEFL'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm', 'keywords':'wolfson stereo audio codec adc dac headphone', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/WM8731_v4.9.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nWM8731CLSEFL\n\nwolfson stereo audio codec adc dac headphone', 'pins':[
            Pin(num='1',name='XTI/MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ADCDAT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='ADCLRC',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='HPVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='LHPOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='RHPOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='HPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='LOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='ROUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VMID',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MICBIAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='MICIN',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RLINEIN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='LLINEIN',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{CSB}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SDIN',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DCVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DBVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='BCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DACDAT',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DACLRC',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'WM8731SEDS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WM8731SEDS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'wolfson stereo audio codec adc dac headphone', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/WM8731_v4.9.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nWM8731SEDS\n\nwolfson stereo audio codec adc dac headphone', 'pins':[
            Pin(num='1',name='DBVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RHPOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='HPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='LOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='ROUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VMID',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='MICBIAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='MICIN',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RLINEIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='LLINEIN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{CSB}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDIN',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XTI/MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DCVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='BCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DACDAT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DACLRC',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='ADCDAT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='ADCLRC',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='HPVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='LHPOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'YM2149', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'YM2149'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'audio ssg 3ch', 'description':'', 'datasheet':'http://www.ym2149.com/ym2149.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nYM2149\n\naudio ssg 3ch', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IOB3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IOB2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IOB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IOB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IOA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IOA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IOA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IOA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IOA3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IOA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='IOA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IOA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{A9}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{SEL}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='BDIR',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='BC2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='BC1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='DA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='DA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='DA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='DA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='DA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='DA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='DA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='DA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='C',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='TEST1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='B',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='IOB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IOB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IOB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IOB4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADAU1979xBCP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADAU1979xBCP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-40-1EP_6x6mm_P0.5mm_EP3.9x3.9mm', 'Package_CSP:LFCSP-40-1EP_6x6mm_P0.5mm_EP3.9x3.9mm'], 'footprint':'Package_CSP:LFCSP-40-1EP_6x6mm_P0.5mm_EP3.9x3.9mm', 'keywords':'Audio ADC I2S TDM', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADAU1979.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nADAU1979xBCP\n\nAudio ADC I2S TDM', 'pins':[
            Pin(num='1',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DVDD',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='IOVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SDATAOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SDATAOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='LRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='BCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='ADDR0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='ADDR1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PLL_FILT',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AIN1N',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='AIN1P',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='AIN2N',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='AIN2P',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='AIN3N',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='AIN3P',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='AIN4N',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='AIN4P',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{PD}/~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='MCLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='SA_MODE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS4345', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS4345'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm', 'Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'stereo 2ch audio codec', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS4344-45-48_F2.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS4345\n\nstereo 2ch audio codec', 'pins':[
            Pin(num='1',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AOUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{DEM}/SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='FILT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='AOUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS4348', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS4348'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm', 'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'stereo 2ch audio codec', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS4344-45-48_F2.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS4348\n\nstereo 2ch audio codec', 'pins':[
            Pin(num='1',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AOUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{DEM}/SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='FILT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='AOUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS5344', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS5344'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm', 'Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'stereo 2ch audio codec', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS5343-44_F5.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS5344\n\nstereo 2ch audio codec', 'pins':[
            Pin(num='1',name='SDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='FILT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='AINL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='AINR',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS8416-xZZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS8416-xZZ'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'audio digital interface receiver', 'description':'', 'datasheet':'https://d3uzseaevmutz1.cloudfront.net/pubs/proDatasheet/CS8416_F3.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nCS8416-xZZ\n\naudio digital interface receiver', 'pins':[
            Pin(num='1',name='RXP3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RXP4/RXSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RXP5/RXSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RXP6/TXSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RXP7/TXSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='AD0/~{CS}/NV/RERR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AD1/CDIN/~{AUDIO}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCL/CCLK/96KHZ',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SDA/CDOUT/RCBL',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U/AD2/GPO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='C/GPO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='RXP2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TX/GPO0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VL',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='RMCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OMCK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='SDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='OSCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='OLRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RXP1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RXP0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RXN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD25120P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD25120P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'isd25120', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD25120P\n\nisd25120', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD25120S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD25120S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'isd25120', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD25120S\n\nisd25120', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD2575E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD2575E'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-I-28_11.8x8mm_P0.55mm', 'Package_SO:TSOP-I-28_11.8x8mm_P0.55mm'], 'footprint':'Package_SO:TSOP-I-28_11.8x8mm_P0.55mm', 'keywords':'isd2575', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD2575E\n\nisd2575', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD2575P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD2575P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'isd2575', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD2575P\n\nisd2575', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD2575S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD2575S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'isd2575', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD2575S\n\nisd2575', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD2590E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD2590E'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-I-28_11.8x8mm_P0.55mm', 'Package_SO:TSOP-I-28_11.8x8mm_P0.55mm', 'Package_SO:TSOP-I-28_11.8x8mm_P0.55mm'], 'footprint':'Package_SO:TSOP-I-28_11.8x8mm_P0.55mm', 'keywords':'isd2590', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD2590E\n\nisd2590', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD2590P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD2590P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'isd2590', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD2590P\n\nisd2590', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISD2590S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISD2590S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'isd2590', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/700027/Winbond/ISD2560/1', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nISD2590S\n\nisd2590', 'pins':[
            Pin(num='1',name='A0/M0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SP+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SP-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='MIC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIC_REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1/M1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ANA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='ANA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{OVF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{EOM}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='XCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2/M2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3/M3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4/M4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5/M5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A6/M6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX98357B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX98357B'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-16-1EP_3x3mm_P0.5mm_EP1.23x1.23mm', 'Package_DFN_QFN:TQFN-16-1EP_3x3mm_P0.5mm_EP1.23x1.23mm'], 'footprint':'Package_DFN_QFN:TQFN-16-1EP_3x3mm_P0.5mm_EP1.23x1.23mm', 'keywords':'tdm i2s left-justified amplifier audio dac', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX98357A-MAX98357B.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nMAX98357B\n\ntdm i2s left-justified amplifier audio dac', 'pins':[
            Pin(num='1',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUTN',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='LRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='BCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='PAD',func=pin_types.UNSPEC,unit=1),
            Pin(num='2',name='GAIN_SLOT',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{SD_MODE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='OUTP',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM5100A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM5100A'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'audio dac 2ch 32bit 384kHz', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/pcm5100a.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM5100A\n\naudio dac 2ch 32bit 384kHz', 'pins':[
            Pin(num='1',name='CPVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='DEMP',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='FLT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FMT',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XSMT',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='LDOO',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CAPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAPM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VNEG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM5101', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM5101'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'audio dac 2ch 32bit 384kHz', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pcm5101.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM5101\n\naudio dac 2ch 32bit 384kHz', 'pins':[
            Pin(num='1',name='CPVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='DEMP',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='FLT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FMT',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XSMT',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='LDOO',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CAPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAPM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VNEG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM5101A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM5101A'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'audio dac 2ch 32bit 384kHz', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/pcm5101a.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM5101A\n\naudio dac 2ch 32bit 384kHz', 'pins':[
            Pin(num='1',name='CPVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='DEMP',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='FLT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FMT',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XSMT',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='LDOO',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CAPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAPM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VNEG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM5102', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM5102'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'audio dac 2ch 32bit 384kHz', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pcm5102.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM5102\n\naudio dac 2ch 32bit 384kHz', 'pins':[
            Pin(num='1',name='CPVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='DEMP',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='FLT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FMT',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XSMT',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='LDOO',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CAPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAPM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VNEG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM5102A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM5102A'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'audio dac 2ch 32bit 384kHz', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/pcm5102a.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM5102A\n\naudio dac 2ch 32bit 384kHz', 'pins':[
            Pin(num='1',name='CPVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='DEMP',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='FLT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='BCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='LRCK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FMT',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XSMT',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='LDOO',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CAPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAPM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VNEG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCM5121PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCM5121PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'audio dac 2ch 32bit 384kHz', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pcm5121.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPCM5121PW\n\naudio dac 2ch 32bit 384kHz', 'pins':[
            Pin(num='1',name='CPVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VCOM/DEMP',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDA/MOSI/ATT2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SCL/MC/ATT1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GPIO5/ATT0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO4/MAST',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO3/AGNS',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='ADR2/GPIO2/DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='MODE1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MODE2/MS',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='GPIO6/FLT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CAPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BCK',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='LRCK',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='ADR1/MISO/FMT',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='XSMT',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='LDOO',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAPM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VNEG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PGA2310PA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PGA2310PA'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'audio volume control 2ch spi', 'description':'', 'datasheet':'https://www.ti.com.cn/cn/lit/gpn/pga2310', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPGA2310PA\n\naudio volume control 2ch spi', 'pins':[
            Pin(num='8',name='~{MUTE}',func=pin_types.INPUT),
            Pin(num='1',name='ZCEN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AGNDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='V_{OUT}R',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='V_{A}+',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='V_{A}-',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='V_{OUT}L',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='AGNDL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='V_{IN}L',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V_{D}+',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='V_{IN}R',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PT2258-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PT2258-S'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_SO:SO-20_12.8x7.5mm_P1.27mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'Volume', 'description':'', 'datasheet':'http://www.princeton.com.tw/Portals/0/Product/PT2258-s.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nPT2258-S\n\nVolume', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='CODE1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CODE2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN5',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RD5107A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RD5107A'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'EG&G RETICON BBD N-channel silicon-gate', 'description':'', 'datasheet':'http://pdf.datasheetarchive.com/indexerfiles/Scans-091/DSAHI00048836.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nRD5107A\n\nEG&G RETICON BBD N-channel silicon-gate', 'pins':[
            Pin(num='1',name='Clock',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='Output',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Input',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Sync',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RE46C318', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RE46C318'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Horn driver Piezo', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22301B.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nRE46C318\n\nHorn driver Piezo', 'pins':[
            Pin(num='1',name='FEED',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='LX',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='V_{O}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='HORNB',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='HORNS',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='HRNEN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SAD512', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SAD512'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'EG&G RETICON BBD N-channel silicon-gate', 'description':'', 'datasheet':'http://thmq.mysteria.cz/em1022/SAD1024.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nSAD512\n\nEG&G RETICON BBD N-channel silicon-gate', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT),
            Pin(num='7',name='Vdd',func=pin_types.PWRIN),
            Pin(num='9',name='Vbb',func=pin_types.PWRIN),
            Pin(num='2',name='IN_A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='02A',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name="OUT_A'",func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='01A',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='01B',func=pin_types.INPUT,unit=2),
            Pin(num='11',name="OUT_B'",func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='OUT_B',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='02B',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='IN_B',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['16', '7', '1', '3', '8', '5', '13', '4', '9', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '16', '7', '14', '15', '10', '13', '4', '9', '11', '1']}] }),
        Part(**{ 'name':'THAT1583', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT1583'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias', 'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias', 'keywords':'diff amp mic preamp', 'description':'', 'datasheet':'http://www.thatcorp.com/datashts/THAT_1583_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTHAT1583\n\ndiff amp mic preamp', 'pins':[
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='Rg2',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='V-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Rg1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IN1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THAT6262', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT6262'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.45x5.45mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.45x5.45mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.45x5.45mm', 'keywords':'dual mic preamp', 'description':'', 'datasheet':'http://www.thatcorp.com/datashts/THAT_626x_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTHAT6262\n\ndual mic preamp', 'pins':[
            Pin(num='1',name='RFB+_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VA+',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CG2_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CG1_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='IN-_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN+_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VA-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CFB-_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VA-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CFB+_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VA+',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VCM',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VAD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='OUT-_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='OUT+_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='RFB-_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DI+_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DI-_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PO+_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PO-_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VA-',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GPO0_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='26',name='GPO1_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='27',name='BSY_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='28',name='DGND',func=pin_types.PWRIN,unit=2),
            Pin(num='29',name='VD',func=pin_types.PWRIN,unit=2),
            Pin(num='30',name='~{CS}',func=pin_types.INPUT,unit=2),
            Pin(num='31',name='SCLK',func=pin_types.INPUT,unit=2),
            Pin(num='32',name='DIN',func=pin_types.INPUT,unit=2),
            Pin(num='33',name='DOUT',func=pin_types.TRISTATE,unit=2),
            Pin(num='34',name='BSY_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='35',name='GPO_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='36',name='GP1_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='16',name='CG2_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='17',name='CG1_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='18',name='IN-_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='19',name='IN+_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='21',name='PO+_CH2',func=pin_types.OUTPUT,unit=3),
            Pin(num='22',name='PO-_CH2',func=pin_types.OUTPUT,unit=3),
            Pin(num='23',name='DI+_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='24',name='DI-_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='37',name='CFB+_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='38',name='CFB-_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='39',name='RFB+_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='40',name='RFB-_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='41',name='OUT+_CH2',func=pin_types.OUTPUT,unit=3),
            Pin(num='42',name='OUT-_CH2',func=pin_types.OUTPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['43', '4', '6', '2', '10', '7', '44', '1', '20', '8', '45', '3', '14', '11', '46', '9', '15', '47', '48', '13', '49', '12', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['28', '33', '27', '25', '29', '31', '35', '30', '32', '34', '36', '26']},{'label': 'uC', 'num': 3, 'pin_nums': ['22', '24', '38', '40', '42', '19', '17', '21', '23', '41', '16', '18', '37', '39']}] }),
        Part(**{ 'name':'THAT6263', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT6263'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.45x5.45mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.45x5.45mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.45x5.45mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.45x5.45mm', 'keywords':'dual mic preamp', 'description':'', 'datasheet':'http://www.thatcorp.com/datashts/THAT_626x_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nTHAT6263\n\ndual mic preamp', 'pins':[
            Pin(num='1',name='RFB+_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VA+',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CG2_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CG1_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='IN-_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN+_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VA-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CFB-_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VA-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CFB+_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VA+',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VCM',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VAD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='OUT-_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='OUT+_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='RFB-_CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DI+_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DI-_CH1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PO+_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PO-_CH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VA-',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GPO0_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='26',name='GPO1_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='27',name='BSY_CH1',func=pin_types.OUTPUT,unit=2),
            Pin(num='28',name='DGND',func=pin_types.PWRIN,unit=2),
            Pin(num='29',name='VD',func=pin_types.PWRIN,unit=2),
            Pin(num='30',name='~{CS}',func=pin_types.INPUT,unit=2),
            Pin(num='31',name='SCLK',func=pin_types.INPUT,unit=2),
            Pin(num='32',name='DIN',func=pin_types.INPUT,unit=2),
            Pin(num='33',name='DOUT',func=pin_types.TRISTATE,unit=2),
            Pin(num='34',name='BSY_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='35',name='GPO_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='36',name='GP1_CH2',func=pin_types.OUTPUT,unit=2),
            Pin(num='16',name='CG2_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='17',name='CG1_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='18',name='IN-_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='19',name='IN+_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='21',name='PO+_CH2',func=pin_types.OUTPUT,unit=3),
            Pin(num='22',name='PO-_CH2',func=pin_types.OUTPUT,unit=3),
            Pin(num='23',name='DI+_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='24',name='DI-_CH2',func=pin_types.INPUT,unit=3),
            Pin(num='37',name='CFB+_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='38',name='CFB-_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='39',name='RFB+_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='40',name='RFB-_CH2',func=pin_types.PASSIVE,unit=3),
            Pin(num='41',name='OUT+_CH2',func=pin_types.OUTPUT,unit=3),
            Pin(num='42',name='OUT-_CH2',func=pin_types.OUTPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '8', '43', '9', '44', '45', '11', '46', '10', '1', '47', '12', '13', '48', '14', '49', '15', '2', '5', '20', '6', '3', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['25', '33', '36', '28', '31', '26', '34', '29', '27', '32', '35', '30']},{'label': 'uC', 'num': 3, 'pin_nums': ['21', '41', '24', '18', '39', '22', '42', '38', '16', '37', '40', '19', '23', '17']}] }),
        Part(**{ 'name':'WM8731CSEFL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WM8731CSEFL'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm', 'Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm', 'keywords':'wolfson stereo audio codec adc dac headphone', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/WM8731_v4.9.pdf', 'search_text':'/usr/share/kicad/symbols/Audio.kicad_sym\nWM8731CSEFL\n\nwolfson stereo audio codec adc dac headphone', 'pins':[
            Pin(num='1',name='XTI/MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ADCDAT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='ADCLRC',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='HPVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='LHPOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='RHPOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='HPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='LOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='ROUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VMID',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MICBIAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='MICIN',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RLINEIN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='LLINEIN',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{CSB}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SDIN',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DCVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DBVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='BCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DACDAT',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DACLRC',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])